Class: Aws::NovaAct::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::NovaAct::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-novaact/client.rb,
sig/client.rbs
Overview
An API client for NovaAct. To construct a client, you need to configure a :region and :credentials.
client = Aws::NovaAct::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateActResponseSuccess, _CreateSessionResponseSuccess, _CreateWorkflowDefinitionResponseSuccess, _CreateWorkflowRunResponseSuccess, _DeleteWorkflowDefinitionResponseSuccess, _DeleteWorkflowRunResponseSuccess, _GetWorkflowDefinitionResponseSuccess, _GetWorkflowRunResponseSuccess, _InvokeActStepResponseSuccess, _ListActsResponseSuccess, _ListModelsResponseSuccess, _ListSessionsResponseSuccess, _ListWorkflowDefinitionsResponseSuccess, _ListWorkflowRunsResponseSuccess, _UpdateActResponseSuccess, _UpdateWorkflowRunResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_act(params = {}) ⇒ Types::CreateActResponse
Creates a new AI task (act) within a session that can interact with tools and perform specific actions.
-
#create_session(params = {}) ⇒ Types::CreateSessionResponse
Creates a new session context within a workflow run to manage conversation state and acts.
-
#create_workflow_definition(params = {}) ⇒ Types::CreateWorkflowDefinitionResponse
Creates a new workflow definition template that can be used to execute multiple workflow runs.
-
#create_workflow_run(params = {}) ⇒ Types::CreateWorkflowRunResponse
Creates a new execution instance of a workflow definition with specified parameters.
-
#delete_workflow_definition(params = {}) ⇒ Types::DeleteWorkflowDefinitionResponse
Deletes a workflow definition and all associated resources.
-
#delete_workflow_run(params = {}) ⇒ Types::DeleteWorkflowRunResponse
Terminates and cleans up a workflow run, stopping all associated acts and sessions.
-
#get_workflow_definition(params = {}) ⇒ Types::GetWorkflowDefinitionResponse
Retrieves the details and configuration of a specific workflow definition.
-
#get_workflow_run(params = {}) ⇒ Types::GetWorkflowRunResponse
Retrieves the current state, configuration, and execution details of a workflow run.
-
#invoke_act_step(params = {}) ⇒ Types::InvokeActStepResponse
Executes the next step of an act, processing tool call results and returning new tool calls if needed.
-
#list_acts(params = {}) ⇒ Types::ListActsResponse
Lists all acts within a specific session with their current status and execution details.
-
#list_models(params = {}) ⇒ Types::ListModelsResponse
Lists all available AI models that can be used for workflow execution, including their status and compatibility information.
-
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists all sessions within a specific workflow run.
-
#list_workflow_definitions(params = {}) ⇒ Types::ListWorkflowDefinitionsResponse
Lists all workflow definitions in your account with optional filtering and pagination.
-
#list_workflow_runs(params = {}) ⇒ Types::ListWorkflowRunsResponse
Lists all workflow runs for a specific workflow definition with optional filtering and pagination.
-
#update_act(params = {}) ⇒ Struct
Updates an existing act's configuration, status, or error information.
-
#update_workflow_run(params = {}) ⇒ Struct
Updates the configuration or state of an active workflow run.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-novaact/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1257 1258 1259 |
# File 'lib/aws-sdk-novaact/client.rb', line 1257 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1260 1261 1262 |
# File 'lib/aws-sdk-novaact/client.rb', line 1260 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/aws-sdk-novaact/client.rb', line 1230 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::NovaAct') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-novaact' context[:gem_version] = '1.9.0' Seahorse::Client::Request.new(handlers, context) end |
#create_act(params = {}) ⇒ Types::CreateActResponse
Creates a new AI task (act) within a session that can interact with tools and perform specific actions.
87 |
# File 'sig/client.rbs', line 87
def create_act: (
|
#create_session(params = {}) ⇒ Types::CreateSessionResponse
Creates a new session context within a workflow run to manage conversation state and acts.
111 |
# File 'sig/client.rbs', line 111
def create_session: (
|
#create_workflow_definition(params = {}) ⇒ Types::CreateWorkflowDefinitionResponse
Creates a new workflow definition template that can be used to execute multiple workflow runs.
123 |
# File 'sig/client.rbs', line 123
def create_workflow_definition: (
|
#create_workflow_run(params = {}) ⇒ Types::CreateWorkflowRunResponse
Creates a new execution instance of a workflow definition with specified parameters.
140 |
# File 'sig/client.rbs', line 140
def create_workflow_run: (
|
#delete_workflow_definition(params = {}) ⇒ Types::DeleteWorkflowDefinitionResponse
Deletes a workflow definition and all associated resources. This operation cannot be undone.
157 |
# File 'sig/client.rbs', line 157
def delete_workflow_definition: (
|
#delete_workflow_run(params = {}) ⇒ Types::DeleteWorkflowRunResponse
Terminates and cleans up a workflow run, stopping all associated acts and sessions.
167 |
# File 'sig/client.rbs', line 167
def delete_workflow_run: (
|
#get_workflow_definition(params = {}) ⇒ Types::GetWorkflowDefinitionResponse
Retrieves the details and configuration of a specific workflow definition.
183 |
# File 'sig/client.rbs', line 183
def get_workflow_definition: (
|
#get_workflow_run(params = {}) ⇒ Types::GetWorkflowRunResponse
Retrieves the current state, configuration, and execution details of a workflow run.
199 |
# File 'sig/client.rbs', line 199
def get_workflow_run: (
|
#invoke_act_step(params = {}) ⇒ Types::InvokeActStepResponse
Executes the next step of an act, processing tool call results and returning new tool calls if needed.
211 |
# File 'sig/client.rbs', line 211
def invoke_act_step: (
|
#list_acts(params = {}) ⇒ Types::ListActsResponse
Lists all acts within a specific session with their current status and execution details.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
236 |
# File 'sig/client.rbs', line 236
def list_acts: (
|
#list_models(params = {}) ⇒ Types::ListModelsResponse
Lists all available AI models that can be used for workflow execution, including their status and compatibility information.
253 |
# File 'sig/client.rbs', line 253
def list_models: (
|
#list_sessions(params = {}) ⇒ Types::ListSessionsResponse
Lists all sessions within a specific workflow run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
264 |
# File 'sig/client.rbs', line 264
def list_sessions: (
|
#list_workflow_definitions(params = {}) ⇒ Types::ListWorkflowDefinitionsResponse
Lists all workflow definitions in your account with optional filtering and pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
279 |
# File 'sig/client.rbs', line 279
def list_workflow_definitions: (
|
#list_workflow_runs(params = {}) ⇒ Types::ListWorkflowRunsResponse
Lists all workflow runs for a specific workflow definition with optional filtering and pagination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
292 |
# File 'sig/client.rbs', line 292
def list_workflow_runs: (
|
#update_act(params = {}) ⇒ Struct
Updates an existing act's configuration, status, or error information.
304 |
# File 'sig/client.rbs', line 304
def update_act: (
|
#update_workflow_run(params = {}) ⇒ Struct
Updates the configuration or state of an active workflow run.
321 |
# File 'sig/client.rbs', line 321
def update_workflow_run: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1250 1251 1252 |
# File 'lib/aws-sdk-novaact/client.rb', line 1250 def waiter_names [] end |