Module: Aws::NovaAct::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-novaact/errors.rb
Overview
When NovaAct returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::NovaAct::Errors::ServiceError < Errors::ServiceError
You can rescue all NovaAct errors using ServiceError:
begin
# do stuff
rescue Aws::NovaAct::Errors::ServiceError
# rescues all NovaAct API errors
end
## Request Context ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
## Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: AccessDeniedException, ConflictException, InternalServerException, ResourceNotFoundException, ServiceQuotaExceededException, ThrottlingException, ValidationException