Class: Aws::NovaAct::Types::CreateSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-novaact/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


311
312
313
314
315
316
317
# File 'lib/aws-sdk-novaact/types.rb', line 311

class CreateSessionRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_definition_nameString

The name of the workflow definition containing the workflow run.

Returns:

  • (String)


311
312
313
314
315
316
317
# File 'lib/aws-sdk-novaact/types.rb', line 311

class CreateSessionRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_run_idString

The unique identifier of the workflow run to create the session in.

Returns:

  • (String)


311
312
313
314
315
316
317
# File 'lib/aws-sdk-novaact/types.rb', line 311

class CreateSessionRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end