Class: Aws::NovaAct::Types::CreateWorkflowDefinitionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-novaact/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-novaact/types.rb', line 356

class CreateWorkflowDefinitionRequest < Struct.new(
  :name,
  :description,
  :export_config,
  :client_token)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

An optional description of the workflow definition’s purpose and functionality.

Returns:

  • (String)


356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-novaact/types.rb', line 356

class CreateWorkflowDefinitionRequest < Struct.new(
  :name,
  :description,
  :export_config,
  :client_token)
  SENSITIVE = [:description]
  include Aws::Structure
end

#export_configTypes::WorkflowExportConfig

Configuration for exporting workflow execution data to Amazon Simple Storage Service.



356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-novaact/types.rb', line 356

class CreateWorkflowDefinitionRequest < Struct.new(
  :name,
  :description,
  :export_config,
  :client_token)
  SENSITIVE = [:description]
  include Aws::Structure
end

#nameString

The name of the workflow definition. Must be unique within your account and region.

Returns:

  • (String)


356
357
358
359
360
361
362
363
# File 'lib/aws-sdk-novaact/types.rb', line 356

class CreateWorkflowDefinitionRequest < Struct.new(
  :name,
  :description,
  :export_config,
  :client_token)
  SENSITIVE = [:description]
  include Aws::Structure
end