Class: Aws::NovaAct::Types::CreateWorkflowDefinitionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NovaAct::Types::CreateWorkflowDefinitionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-novaact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The current status of the workflow definition after creation.
Instance Attribute Details
#status ⇒ String
The current status of the workflow definition after creation.
371 372 373 374 375 |
# File 'lib/aws-sdk-novaact/types.rb', line 371 class CreateWorkflowDefinitionResponse < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |