Class: Aws::NovaAct::Types::CreateWorkflowRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-novaact/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_infoTypes::ClientInfo

Information about the client making the request, including compatibility version and SDK version.

Returns:



404
405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-novaact/types.rb', line 404

class CreateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :model_id,
  :client_token,
  :log_group_name,
  :client_info)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


404
405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-novaact/types.rb', line 404

class CreateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :model_id,
  :client_token,
  :log_group_name,
  :client_info)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The CloudWatch log group name for storing workflow execution logs.

Returns:

  • (String)


404
405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-novaact/types.rb', line 404

class CreateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :model_id,
  :client_token,
  :log_group_name,
  :client_info)
  SENSITIVE = []
  include Aws::Structure
end

#model_idString

The ID of the AI model to use for workflow execution.

Returns:

  • (String)


404
405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-novaact/types.rb', line 404

class CreateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :model_id,
  :client_token,
  :log_group_name,
  :client_info)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_definition_nameString

The name of the workflow definition to execute.

Returns:

  • (String)


404
405
406
407
408
409
410
411
412
# File 'lib/aws-sdk-novaact/types.rb', line 404

class CreateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :model_id,
  :client_token,
  :log_group_name,
  :client_info)
  SENSITIVE = []
  include Aws::Structure
end