Class: Aws::NovaAct::Types::CreateWorkflowRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NovaAct::Types::CreateWorkflowRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-novaact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The initial status of the workflow run after creation.
-
#workflow_run_id ⇒ String
The unique identifier for the created workflow run.
Instance Attribute Details
#status ⇒ String
The initial status of the workflow run after creation.
424 425 426 427 428 429 |
# File 'lib/aws-sdk-novaact/types.rb', line 424 class CreateWorkflowRunResponse < Struct.new( :workflow_run_id, :status) SENSITIVE = [] include Aws::Structure end |
#workflow_run_id ⇒ String
The unique identifier for the created workflow run.
424 425 426 427 428 429 |
# File 'lib/aws-sdk-novaact/types.rb', line 424 class CreateWorkflowRunResponse < Struct.new( :workflow_run_id, :status) SENSITIVE = [] include Aws::Structure end |