Class: Aws::NovaAct::Types::DeleteWorkflowRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-novaact/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#workflow_definition_nameString

The name of the workflow definition containing the workflow run.

Returns:

  • (String)


465
466
467
468
469
470
# File 'lib/aws-sdk-novaact/types.rb', line 465

class DeleteWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_run_idString

The unique identifier of the workflow run to delete.

Returns:

  • (String)


465
466
467
468
469
470
# File 'lib/aws-sdk-novaact/types.rb', line 465

class DeleteWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id)
  SENSITIVE = []
  include Aws::Structure
end