Class: Aws::NovaAct::Types::DeleteWorkflowRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NovaAct::Types::DeleteWorkflowRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-novaact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the workflow run after deletion request.
Instance Attribute Details
#status ⇒ String
The status of the workflow run after deletion request.
478 479 480 481 482 |
# File 'lib/aws-sdk-novaact/types.rb', line 478 class DeleteWorkflowRunResponse < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |