Class: Aws::NovaAct::Types::GetWorkflowRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-novaact/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#workflow_definition_nameString

The name of the workflow definition containing the workflow run.

Returns:

  • (String)


543
544
545
546
547
548
# File 'lib/aws-sdk-novaact/types.rb', line 543

class GetWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_run_idString

The unique identifier of the workflow run to retrieve.

Returns:

  • (String)


543
544
545
546
547
548
# File 'lib/aws-sdk-novaact/types.rb', line 543

class GetWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id)
  SENSITIVE = []
  include Aws::Structure
end