Class: Aws::NovaAct::Types::GetWorkflowRunResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::NovaAct::Types::GetWorkflowRunResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-novaact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ended_at ⇒ Time
The timestamp when the workflow run completed execution, if applicable.
-
#log_group_name ⇒ String
The CloudWatch log group name for this workflow run’s logs.
-
#model_id ⇒ String
The ID of the AI model being used for this workflow run.
-
#started_at ⇒ Time
The timestamp when the workflow run started execution.
-
#status ⇒ String
The current execution status of the workflow run.
-
#workflow_run_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow run.
-
#workflow_run_id ⇒ String
The unique identifier of the workflow run.
Instance Attribute Details
#ended_at ⇒ Time
The timestamp when the workflow run completed execution, if applicable.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/aws-sdk-novaact/types.rb', line 581 class GetWorkflowRunResponse < Struct.new( :workflow_run_arn, :workflow_run_id, :status, :started_at, :ended_at, :model_id, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#log_group_name ⇒ String
The CloudWatch log group name for this workflow run’s logs.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/aws-sdk-novaact/types.rb', line 581 class GetWorkflowRunResponse < Struct.new( :workflow_run_arn, :workflow_run_id, :status, :started_at, :ended_at, :model_id, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#model_id ⇒ String
The ID of the AI model being used for this workflow run.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/aws-sdk-novaact/types.rb', line 581 class GetWorkflowRunResponse < Struct.new( :workflow_run_arn, :workflow_run_id, :status, :started_at, :ended_at, :model_id, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The timestamp when the workflow run started execution.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/aws-sdk-novaact/types.rb', line 581 class GetWorkflowRunResponse < Struct.new( :workflow_run_arn, :workflow_run_id, :status, :started_at, :ended_at, :model_id, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current execution status of the workflow run.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/aws-sdk-novaact/types.rb', line 581 class GetWorkflowRunResponse < Struct.new( :workflow_run_arn, :workflow_run_id, :status, :started_at, :ended_at, :model_id, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#workflow_run_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow run.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/aws-sdk-novaact/types.rb', line 581 class GetWorkflowRunResponse < Struct.new( :workflow_run_arn, :workflow_run_id, :status, :started_at, :ended_at, :model_id, :log_group_name) SENSITIVE = [] include Aws::Structure end |
#workflow_run_id ⇒ String
The unique identifier of the workflow run.
581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/aws-sdk-novaact/types.rb', line 581 class GetWorkflowRunResponse < Struct.new( :workflow_run_arn, :workflow_run_id, :status, :started_at, :ended_at, :model_id, :log_group_name) SENSITIVE = [] include Aws::Structure end |