Class: Aws::NovaAct::Types::UpdateWorkflowRunRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-novaact/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#statusString

The new status to set for the workflow run.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-novaact/types.rb', line 1183

class UpdateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_definition_nameString

The name of the workflow definition containing the workflow run.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-novaact/types.rb', line 1183

class UpdateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_run_idString

The unique identifier of the workflow run to update.

Returns:

  • (String)


1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-novaact/types.rb', line 1183

class UpdateWorkflowRunRequest < Struct.new(
  :workflow_definition_name,
  :workflow_run_id,
  :status)
  SENSITIVE = []
  include Aws::Structure
end