Class: Aws::NovaAct::Types::CreateWorkflowDefinitionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NovaAct::Types::CreateWorkflowDefinitionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-novaact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#description ⇒ String
An optional description of the workflow definition’s purpose and functionality.
-
#export_config ⇒ Types::WorkflowExportConfig
Configuration for exporting workflow execution data to Amazon Simple Storage Service.
-
#name ⇒ String
The name of the workflow definition.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-novaact/types.rb', line 356 class CreateWorkflowDefinitionRequest < Struct.new( :name, :description, :export_config, :client_token) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
An optional description of the workflow definition’s purpose and functionality.
356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-novaact/types.rb', line 356 class CreateWorkflowDefinitionRequest < Struct.new( :name, :description, :export_config, :client_token) SENSITIVE = [:description] include Aws::Structure end |
#export_config ⇒ Types::WorkflowExportConfig
Configuration for exporting workflow execution data to Amazon Simple Storage Service.
356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-novaact/types.rb', line 356 class CreateWorkflowDefinitionRequest < Struct.new( :name, :description, :export_config, :client_token) SENSITIVE = [:description] include Aws::Structure end |
#name ⇒ String
The name of the workflow definition. Must be unique within your account and region.
356 357 358 359 360 361 362 363 |
# File 'lib/aws-sdk-novaact/types.rb', line 356 class CreateWorkflowDefinitionRequest < Struct.new( :name, :description, :export_config, :client_token) SENSITIVE = [:description] include Aws::Structure end |