Class: Aws::NovaAct::Types::GetWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NovaAct::Types::GetWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-novaact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#workflow_definition_name ⇒ String
The name of the workflow definition containing the workflow run.
-
#workflow_run_id ⇒ String
The unique identifier of the workflow run to retrieve.
Instance Attribute Details
#workflow_definition_name ⇒ String
The name of the workflow definition containing the workflow run.
543 544 545 546 547 548 |
# File 'lib/aws-sdk-novaact/types.rb', line 543 class GetWorkflowRunRequest < Struct.new( :workflow_definition_name, :workflow_run_id) SENSITIVE = [] include Aws::Structure end |
#workflow_run_id ⇒ String
The unique identifier of the workflow run to retrieve.
543 544 545 546 547 548 |
# File 'lib/aws-sdk-novaact/types.rb', line 543 class GetWorkflowRunRequest < Struct.new( :workflow_definition_name, :workflow_run_id) SENSITIVE = [] include Aws::Structure end |