Class: Aws::NovaAct::Types::UpdateWorkflowRunRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::NovaAct::Types::UpdateWorkflowRunRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-novaact/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The new status to set for the workflow run.
-
#workflow_definition_name ⇒ String
The name of the workflow definition containing the workflow run.
-
#workflow_run_id ⇒ String
The unique identifier of the workflow run to update.
Instance Attribute Details
#status ⇒ String
The new status to set for the workflow run.
1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-novaact/types.rb', line 1183 class UpdateWorkflowRunRequest < Struct.new( :workflow_definition_name, :workflow_run_id, :status) SENSITIVE = [] include Aws::Structure end |
#workflow_definition_name ⇒ String
The name of the workflow definition containing the workflow run.
1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-novaact/types.rb', line 1183 class UpdateWorkflowRunRequest < Struct.new( :workflow_definition_name, :workflow_run_id, :status) SENSITIVE = [] include Aws::Structure end |
#workflow_run_id ⇒ String
The unique identifier of the workflow run to update.
1183 1184 1185 1186 1187 1188 1189 |
# File 'lib/aws-sdk-novaact/types.rb', line 1183 class UpdateWorkflowRunRequest < Struct.new( :workflow_definition_name, :workflow_run_id, :status) SENSITIVE = [] include Aws::Structure end |